==> guile-2.0.12-1-armv7h.pkg.tar.xz: usr/lib/guile/2.0/ccache/oop/goops/simple.go <==
GOOF----LE-4-2.0       ] D 4  hr      ] g  guile	 	g  define-module*	 	 	g  oop	g  goops	g  simple		 	
g  filenameS	f  oop/goops/simple.scm	g  importsS	
g  	accessors	
 	 	 	g  exportsS	g  define-class	 	g  set-current-module	 	 	g  make-syntax-transformer	 	 	g  macro	g  $sc-dispatch	 	 	g  any	g  each-any	 	!g  
syntax-object	"g  $define-class-with-accessors-keywords	#g  top	$# 	%g  ribcage	&g  dummy	'g  arg	(&' 	)g  m-8M8vjIgDxTrK@qwqDovbaU-1378	*)# 	+*$ 	,f  l-8M8vjIgDxTrK@qwqDovbaU-1383	-f  l-8M8vjIgDxTrK@qwqDovbaU-1384	.,- 	/%(+. 	0% 	1g  x	21 	3* 	4f  l-8M8vjIgDxTrK@qwqDovbaU-1380	54 	6%235 	7$/06 	8g  hygiene	98 	:!"79 	;g  syntax-violation	<; 	=; 	>f  -source expression failed to match any pattern	?g  module-use!	@g  module-public-interface	Ag  current-module	Bg  resolve-interface	C C 5 h     ]4	
5 4 >  "  G   4 :  h   >   ]C6       g  dummy
		 g  arg		  			   C=>   h(      ]	4 5$  @ 6             g  x
		" g  tmp		"  g  filenamef  oop/goops/simple.scm
	
 		"  g  
macro-typeg  syntax-rulesg  patternsg  argg  ...   C5R?i4@i4Ai5 54BiC56        g  m
		,  g  filenamef  oop/goops/simple.scm		
w		
|		&		
		
		 		
	
 		
   C6 

==> guile-2.0.13-1.1-armv7h.pkg.tar.xz: usr/lib/guile/2.0/ccache/oop/goops/simple.go <==
GOOF----LE-4-2.0       ] D 4  hr      ] g  guile	 	g  define-module*	 	 	g  oop	g  goops	g  simple		 	
g  filenameS	f  oop/goops/simple.scm	g  importsS	
g  	accessors	
 	 	 	g  exportsS	g  define-class	 	g  set-current-module	 	 	g  make-syntax-transformer	 	 	g  macro	g  $sc-dispatch	 	 	g  any	g  each-any	 	!g  
syntax-object	"g  $define-class-with-accessors-keywords	#g  top	$# 	%g  ribcage	&g  dummy	'g  arg	(&' 	)g  m-SUbUsI$1vb$HKRYtwtHOOo-1315	*)# 	+*$ 	,f  l-SUbUsI$1vb$HKRYtwtHOOo-1320	-f  l-SUbUsI$1vb$HKRYtwtHOOo-1321	.,- 	/%(+. 	0% 	1g  x	21 	3* 	4f  l-SUbUsI$1vb$HKRYtwtHOOo-1317	54 	6%235 	7$/06 	8g  hygiene	98 	:!"79 	;g  syntax-violation	<; 	=; 	>f  -source expression failed to match any pattern	?g  module-use!	@g  module-public-interface	Ag  current-module	Bg  resolve-interface	C C 5 h     ]4	
5 4 >  "  G   4 :  h   >   ]C6       g  dummy
		 g  arg		  			   C=>   h(      ]	4 5$  @ 6             g  x
		" g  tmp		"  g  filenamef  oop/goops/simple.scm
	
 		"  g  
macro-typeg  syntax-rulesg  patternsg  argg  ...   C5R?i4@i4Ai5 54BiC56        g  m
		,  g  filenamef  oop/goops/simple.scm		
w		
|		&		
		
		 		
	
 		
   C6 
